==> scorchful-0.16.0%2B1.21.9-sources.jar: com/github/thedeathlycow/scorchful/item/FireChargeThrower.java <==
package com.github.thedeathlycow.scorchful.item;

import com.github.thedeathlycow.scorchful.config.ScorchfulConfig;
import net.fabricmc.fabric.api.event.player.UseItemCallback;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1674;
import net.minecraft.class_1677;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3542;
import net.minecraft.class_3855;
import net.minecraft.class_6088;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class FireChargeThrower implements UseItemCallback {

    private static final int FIRE_CHARGE_COOL_DOWN = 20;

    @Override
    public class_1269 interact(class_1657 player, class_1937 world, class_1268 hand) {
        if (player.method_7325()) {
            return class_1269.field_5811;
        }

        FireballFactory throwingTypes = ScorchfulConfig.getCombatConfig().getFireBallThrownType();

        class_1799 stack = player.method_5998(hand);
        if (!stack.method_31574(class_1802.field_8814) || throwingTypes == FireballFactory.DISABLED) {
            return class_1269.field_5811;
        }
        if (player.method_7357().method_7904(stack)) {
            return class_1269.field_5814;
        }

        // spawn fire charge entity
        if (!world.method_8608()) {
            class_243 rotation = player.method_5720();
            class_3855 fireball = throwingTypes.create(world, player, rotation);

            if (fireball == null) {
                return class_1269.field_5811;
            }

            fireball.method_5814(fireball.method_23317(), player.method_23323(0.5) + 0.5, fireball.method_23321());
            fireball.method_16936(stack);
            world.method_8649(fireball);
            world.method_8444(null, class_6088.field_31176, player.method_24515(), 0);
        }

        // decrement stack
        if (!player.method_68878()) {
            stack.method_7934(1);
        }
        player.method_7357().method_62835(stack, FIRE_CHARGE_COOL_DOWN);

        return class_1269.field_5812;
    }

    public enum FireballFactory implements class_3542 {
        DISABLED("disabled") {
            @Override
            @Nullable
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return null;
            }
        },
        SMALL("small") {
            @Override
            @NotNull
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return new class_1677(
                        world, player,
                        velocity
                );
            }
        },
        LARGE("large") {
            @Override
            @NotNull
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return new class_1674(
                        world, player,
                        velocity, 1
                );
            }
        };

        private final String name;

        FireballFactory(String name) {
            this.name = name;
        }

        @Nullable
        public abstract class_3855 create(class_1937 world, class_1657 player, class_243 velocity);


        @Override
        public String method_15434() {
            return this.name;
        }
    }
}

==> scorchful-0.16.2%2B1.21.10-sources.jar: com/github/thedeathlycow/scorchful/item/FireChargeThrower.java <==
package com.github.thedeathlycow.scorchful.item;

import com.github.thedeathlycow.scorchful.config.ScorchfulConfig;
import net.fabricmc.fabric.api.event.player.UseItemCallback;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1674;
import net.minecraft.class_1677;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1937;
import net.minecraft.class_243;
import net.minecraft.class_3542;
import net.minecraft.class_3855;
import net.minecraft.class_6088;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class FireChargeThrower implements UseItemCallback {

    private static final int FIRE_CHARGE_COOL_DOWN = 20;

    @Override
    public class_1269 interact(class_1657 player, class_1937 world, class_1268 hand) {
        if (player.method_7325()) {
            return class_1269.field_5811;
        }

        FireballFactory throwingTypes = ScorchfulConfig.getItemConfig().getFireBallThrownType();

        class_1799 stack = player.method_5998(hand);
        if (!stack.method_31574(class_1802.field_8814) || throwingTypes == FireballFactory.DISABLED) {
            return class_1269.field_5811;
        }
        if (player.method_7357().method_7904(stack)) {
            return class_1269.field_5814;
        }

        // spawn fire charge entity
        if (!world.method_8608()) {
            class_243 rotation = player.method_5720();
            class_3855 fireball = throwingTypes.create(world, player, rotation);

            if (fireball == null) {
                return class_1269.field_5811;
            }

            fireball.method_5814(fireball.method_23317(), player.method_23323(0.5) + 0.5, fireball.method_23321());
            fireball.method_16936(stack);
            world.method_8649(fireball);
            world.method_8444(null, class_6088.field_31176, player.method_24515(), 0);
        }

        // decrement stack
        if (!player.method_68878()) {
            stack.method_7934(1);
        }
        player.method_7357().method_62835(stack, FIRE_CHARGE_COOL_DOWN);

        return class_1269.field_5812;
    }

    public enum FireballFactory implements class_3542 {
        DISABLED("disabled") {
            @Override
            @Nullable
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return null;
            }
        },
        SMALL("small") {
            @Override
            @NotNull
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return new class_1677(
                        world, player,
                        velocity
                );
            }
        },
        LARGE("large") {
            @Override
            @NotNull
            public class_3855 create(class_1937 world, class_1657 player, class_243 velocity) {
                return new class_1674(
                        world, player,
                        velocity, 1
                );
            }
        };

        private final String name;

        FireballFactory(String name) {
            this.name = name;
        }

        @Nullable
        public abstract class_3855 create(class_1937 world, class_1657 player, class_243 velocity);


        @Override
        public String method_15434() {
            return this.name;
        }
    }
}
